vdoc.methods.api package | vdoc 0.19.0 documentation

Skip to content

# vdoc.methods.api package

## Submodules

## vdoc.methods.api.project_categories module

Contains all projects REST API methods.

vdoc.methods.api.project_categories.list_project_categories_impl()

  Lists all project categories.

  Return type:

    `list`[`ProjectCategory`]

  Returns:

    A list of all projects.

## vdoc.methods.api.projects module

Contains all projects REST API methods.

vdoc.methods.api.projects.get_project_version_impl(name, version)

  Returns the requested version of the project.

  Parameters:

    - name (`str`) – The project name.

    - version (`str`) – The requested version of the project.

  Return type:

    `str`

  Returns:

    The requested version of the project.

vdoc.methods.api.projects.list_project_versions_impl(name)

  Lists all available versions of a project.

  Parameters:

    name (`str`) – The project name.

  Return type:

    `list`[`str`]

  Returns:

    A list of all available versions of the project.

vdoc.methods.api.projects.list_projects_impl()

  Lists all projects.

  Return type:

    `list`[`Project`]

  Returns:

    A list of all projects.

vdoc.methods.api.projects.upload_project_version_impl(name, version, file)

  Processes the uploaded documentation.

  Parameters:

    - name (`str`) – The project name.

    - version (`str`) – The version of the project.

    - file (`UploadFile`) – The uploaded file.

  Raises:

    - InvalidProjectName – If the project name is invalid.

    - InvalidVersion – If the project version is invalid.

    - ProjectVersionAlreadyExists – If the uploaded version already exists for the project.

    - UploadedFileInvalid – If the uploaded file’s content type is invalid.

    - UploadedFileInvalid – If the uploaded file’s name is invalid.

    - UploadedFileInvalid – If the uploaded documentation ZIP is invalid.

    - UploadedFileInvalid – If the uploaded documentation ZIP doesn’t contain an index.html file.

  Return type:

    `JSONResponse`

  Returns:

    _description_

## Module contents

Contains all REST API methods.

vdoc.methods package
vdoc.methods.cli package